.. _changelog:

=========
Changelog
=========

Kallithea project doesn't keep its changelog here.  We refer you to our Mercurial logs_ .

.. _logs: https://kallithea-scm.org/repos/kallithea/changelog
